import pandas as pd

def clean_dataframe(df):
    """Cleans a DataFrame by:
    - Replacing NaN values with 0 for numeric columns.
    - Replacing NaN values with 'Unknown' for non-numeric columns.
    - Stripping leading/trailing whitespace from string columns.
    """
    df = df.copy()  # Work on a copy to avoid SettingWithCopyWarning

    for col in df.columns:
        if pd.api.types.is_numeric_dtype(df[col]):
            df[col] = df[col].fillna(0)  # Replace NaN with 0 in numeric columns
        else:
            df[col] = df[col].astype(str).str.strip().replace({"nan": "Unknown", "None": "Unknown"})  # Handle NaN in strings

    return df
